#!/usr/bin/env python3

import requests as r
import aiohttp
import asyncio
import json
import elasticsearch
from datetime import datetime
def create_indice(host, name, settings=None):
    try:
        url = host + '/' +  name
        if settings:
            resp = requests.put(url, json=settings)
            return resp.text
        else:
            resp = requests.put(url)
            return resp.json()
    except ConnectionError as e:
        print(e)


async def insert_doc(host, index, doc, id=None):
    if id is None:
        path = host + f"/{index}/_doc/"
        r = requests.post(path, json=doc)
        return r
    else:
        path = host + f"/{index}/_doc/{id}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.post(path, json=doc) as r:
                    return  await r.text()
        except Exception as e:
            print(e)

async def search(host, query, size=0, index=None):
    if index:
        path = host + f"/{index}/_search?size={size}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(path, json=query) as r:
                    data = await r.json()
                    return data
        except ConnectionError as e:
            print(e)
    else:
        path = host + f"/_search?size={size}"
        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(path, json=query) as r:
                    data = await r.json()
                    return data
        except ConnectionError as e:
            print(e)

def content_search(es_host, index, search_term, site, sort="asc", limit=25):
    es = elasticsearch.Elasticsearch([es_host])

    if site == "discord" or "telegram" or "twitter":
        q = {"sort": [{"date": {"order": sort}}],
             "query": {"simple_query_string": {"query": search_term, "fields": ["m", "sn", "cn", "username", "ut", "group"]}}}
    if site == "reddit":
        q = {
            "query": {
                "simple_query_string": {
                           "query": search_term,
                           "fields": ["body", "post-title"]
                }
            }
        }

    data = es.search(body=q, index=index, size=limit)
    return data

def search_by_user(es_host, index, username, site, limit=25):
    es = elasticsearch.Elasticsearch([CONFIG.es_host])
    if site == "discord" or "telegram":
        q = {"query": {"simple_query_string": {"query": username, "fields": ["ut"]}}}

    if site == "twitter":
        q = {"query": {"simple_query_string": {"query": username, "fields": ["username"]}}}
    if site == "reddit":
        q = {"query": {"simple_query_string": {"query": username, "fields": ["op", "author"]}}}

    data = es.search(body=q, index=index, size=limit)
    return data

def date_search(es_host, index, date_str, sort="desc", limit=25):
    """returns all messages from the specifed date to now"""
    now = datetime.now()
    q = {"sort": [{"date": {"order": sort}}], "query": {"range": {"date": {"gte": date_str, "lte": str(now.isoformat())}}}}
    data = asyncio.run(search(es_host, q, limit, index))
    return data

def get_count(es_host, index=None, **kwargs):
    user_count = False
    website = "none"
    for key, value in kwargs.items():
        if key == "user" and value == True:
            user_count = True
        if key == "website":
            website = value

    link = f"{es_host}/"
    count = 0
    if user_count:
        if website == "twitter":
            q = {
                "aggs": {
                    "type_count": {
                        "cardinality": {
                            "field": "username.keyword"
                        }
                    }
                }
            }

            resp = r.post(link + index + "/_search?size=0", json=q)
            data = resp.json()
            print(data)
            data = data["aggregations"]["type_count"]["value"]
            count = int(data)
            return count
        if website == "discord" or "telegram":
            q = {
                "aggs": {
                    "type_count": {
                        "cardinality": {
                            "field": "ut.keyword"
                        }
                    }
                }
            }
            resp = r.post(link + index + "/_search?size=0", json=q)
            data = resp.json()
            print(data)
            data = data["aggregations"]["type_count"]["value"]
            count = int(data)
            return count
        if website == "reddit":
            q1  =  {
                    "aggs": {
                        "type_count": {
                            "cardinality": {
                                "field": "op.keyword"
                            }
                        }
                    }
                }

            q2  =  {
                    "aggs": {
                        "type_count": {
                            "cardinality": {
                                "field": "op.keyword"
                            }
                        }
                    }
                }

            resp1 = r.get(link + index + "/_search?size=0", json=q1)
            resp2 = r.get(link + index + "/_search?size=0", json=q)

    else:
        resp = r.get(link + index + "/_count")
        data = resp.json()
        count = int(data["count"])
        return count



#!/usr/bin/env python3

import logging
from ungi_utils.Config import UngiConfig
from pathlib import Path

class UngiLogger:
    def __init__(config):
        self.log_format = config.log_format
        self.log_dir = config.log_dir
        self.log_level = config.log_level
    def get_logger(self):
        logger = logging.getLogger(__name__)
        LogFormat = logging.Formatter('%(asctime)s : %(levelname)s : %(name)s : %(message)s')
        file_handler = logging.FileHandler(Path(f"{self.log_dir}/{__name__}.log"))
        file_handler.setFormatter(LogFormat)
        logger.addHandler(file_handler)
        logger.setLevel = self.log_level
        self.logger = logger
        return self.logger



#!/usr/bin/env python3

from configparser import ConfigParser
import os

"""
This handles all of our config needs for UNGI
"""


def config(section, option, filename):
    """
    Used to load the config and parse its values
    """
    parser = ConfigParser()
    parser.read(filename)
    if parser.has_section(section):
        val = parser.get(section, option)
        return val


def list_index(section, filename):
    """
    used to list es indexes from ini file
    """
    parser = ConfigParser()
    parser.read(filename)
    index_list = []
    for x in parser[f"{section}"]:
        index_list.append(parser.get(f"{section}", x))
    return index_list


def auto_load(str_in=None):
    """
    used to load the config. the str_in is to be used for the path
    if it is None (when the user does not pass a argument) it will
    load the path from the env var UNGI_CONFIG
    """
    if str_in:
        return str_in
    else:
        config_path = os.environ["UNGI_CONFIG"]
        return config_path


class UngiConfig:
    """
    A Common config class used for bots and ungi cli tools
    only input is a path to the ini file
    """
    def __init__(self, path):

        # CONFIGURATION FOR BOTS
        self.config_path = path
        self.es_host = config("ES", "host", self.config_path) # elasticsearch
        self.db_path = config("DB", "path", self.config_path) # loot db path
        self.sql_script = config("DB", "script", self.config_path) #sql script

        # INDEX

        self.discord = config("INDEX", "discord", self.config_path) #discord index
        self.reddit = config("INDEX", "reddit", self.config_path) #reddit index
        self.telegram = config("INDEX", "telegram", self.config_path) #telegram index
        self.loot = config("INDEX", "loot", self.config_path) # loot index
        self.crawler = config("INDEX", "crawler", self.config_path)
        self.twitch = config("INDEX", "twitch", self.config_path)
        self.reddit_client_id = config("REDDIT", "client_id", self.config_path)
        self.reddit_client_secret = config("REDDIT", "client_secret", self.config_path)
        self.reddit_client_username = config("REDDIT", "username", self.config_path)
        self.reddit_client_password = config("REDDIT", "password", self.config_path)
        self.reddit_client_user_agent = config("REDDIT", "user_agent", self.config_path)
        self.telegram_media = config("TELEGRAM", "media", self.config_path)
        self.telegram_store_media = config("TELEGRAM", "store_media", self.config_path)
        self.timezone = config("TIME", "timezone", self.config_path)
        self.twitter = config("INDEX", "twitter", self.config_path)
        if self.telegram_store_media == "True" or self.telegram_store_media == "true":
            self.telegram_store_media = True
        else:
            self.telegram_store_media = False

        # CONFIGURATION FOR SERVER
        self.broker = config("CELERY", "broker_url", self.config_path)
        self.alert_type = config("ALERTS", "type", self.config_path)
        self.server_port = config("SERVER", "server_port", self.config_path)
        self.project_name = config("APP", "name", self.config_path) #to name the project
        self.project_description = config("APP", "description", self.config_path)
        self.secret = config("APP", "web_secret", self.config_path)
        # used for bots
        self.server_host = config("SERVER", "server_host", self.config_path)

        # email config
        self.smtp_host = config("ALERTS", "smtp_host", self.config_path)
        self.smtp_port = config("ALERTS", "smtp_port", self.config_path)
        self.smtp_username = config("ALERTS", "smtp_username", self.config_path)
        self.smtp_password = config("ALERTS", "smtp_password", self.config_path)
        self.to_email = config("ALERTS", "to_email", self.config_path)
        self.from_email = config("ALERTS", "from_email", self.config_path)

        # Discord Bot config (for alerts)
        self.alert_discord = config("ALERTS", "discord-token", self.config_path)

        # matrix config
        self.matrix_config = config("ALERTS", "matrix_config", self.config_path)
        self.matrix_username = config("ALERTS", "matrix_username", self.config_path)
        self.matrix_password = config("ALERTS", "matrix_password", self.config_path)
        self.matrix_session_name = config("ALERTS", "matrix_session_name", self.config_path)
        self.matrix_roomid = config("ALERTS", "matrix_roomid", self.config_path)
        self.matrix_rooms = []
        try:
            for roomid in self.matrix_roomid.split(","):
                self.matrix_rooms.append(roomid.rstrip())
        except ValueError:
            self.matrix_rooms.append(self.matrix_roomid.rstrip())
        self.matrix_home_server = config("ALERTS", "matrix_home_server", self.config_path)

        self.webhook = config("ALERTS", "webhook", self.config_path).rstrip()
        self.webhooks = []
        for endpoint in self.webhook.split(","):
            self.webhooks.append(endpoint)

        if self.alert_type == "all":
            self.use_email = True
            self.use_matrix = True
            self.use_telegram = True
            self.use_discord = True
            self.use_webhooks = True

        if self.alert_type == "email":
            self.use_email = True
        if self.alert_type == "matrix":
            self.use_matrix = True
        if self.alert_type == "discord":
            self.use_discord = True
        if self.alert_type == "telegram":
            self.use_telegram = True
        if self.alert_type == "webhooks":
            self.use_webhooks = True
        # twitter bot stuff

        self.proxy_type = config("TWITTER", "proxy_type", self.config_path)
        self.proxy_host = config("TWITTER", "proxy_type", self.config_path)
        self.proxy_port = config("TWITTER", "proxy_type", self.config_path)
        self.tor_control_port = config("TOR", "control_port", self.config_path)
        self.tor_pass = config("TOR", "pass", self.config_path)
        self.imgbb_api = config("API", "imgbb", self.config_path)

        # Stuff Used for ungi chat bots, so users can search the backend
        self.search_bot_email = config("SEARCH_BOT", "email", self.config_path) # guilded
        self.search_bot_password = config("SEARCH_BOT", "password", self.config_path) # guilded
        self.search_bot_discord = config("SEARCH_BOT", "discord_token", self.config_path)

        # UNGI web
        self.web_port = config("WEB", "port", self.config_path)
        self.web_name = config("WEB", "name", self.config_path)

        self.session_dir = config("TELEGRAM", "session_dir", self.config_path)

        # bot startup configuration
        self.use_discord = False
        self.use_reddit = False
        self.use_telegram = False
        self.use_twitch = False
        if config("BOTS", "discord", self.config_path).lower() == "true":
            self.use_discord = True
        if config("BOTS", "reddit", self.config_path).lower() == "true":
            self.use_reddit = True
        if config("BOTS", "telegram", self.config_path).lower() == "true":
            self.use_telegram = True
        if config("BOTS", "twitch", self.config_path).lower() == "true":
            self.use_twitch = True

        # Minute Man Config

        self.crawl_secret = config("MinuteMan", "secret", self.config_path)
        self.crawl_theme = config("MinuteMan", "theme", self.config_path)
        self.crawl_db = config("MinuteMan", "db", self.config_path)
        if self.crawl_db:
            self.crawl_use_own_db = True
        else:
            self.crawl_db = self.db_path


        self.log_dir = config()



#!/usr/bin/env python3

"""
UNGI - Unseen Giants Intelligence
This script is for CRUD operations.
"""

import sqlite3
from hashlib import sha256
def hash_(str_in):
    return sha256(bytes(str_in, encoding="utf8")).hexdigest()
from urllib.parse import urlparse
def get_path(url):
    """
    used to return the telegram
    group name.
    """
    name = urlparse(url)
    return name.path.split("/")[1]
def db_init(path, sql_file):
    """
    used for setup (main.py -i)
    reads in a sql file conatining sql commands to
    setup the sqlite3 database.
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        with open(sql_file, "r", encoding="utf-8") as script_file:
            script_sql = script_file.read()
        cur.executescript(script_sql)
        conn.commit()
    except sqlite3.DatabaseError as e:
        print(e)


def create_operation(path, name, description=None):
    """
    Ops are used as a way to track which entities belong to a
    Mission/Operation. its to prevent all the data from globing together
    """
    try:
        if description is None:
            discription = "No dscription provided"
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO operations(operation_name, operation_description) VALUES(?,?)", (name, description))
        conn.commit()
        return {"Status": "True"}
    except sqlite3.IntegrityError as duplicate_op:
        return {"Status": "Error Duplicate"}

def add_subreddit(path, subreddit, operation_id):
    """
    Adds a Subbreddit to the database.
    Requires: Subreddit name, db path, operation id
    the reddit bot will select all subreddits from the table and scrape them.
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("""INSERT INTO reddit(subreddit, operation_id) VALUES(?,?)""", (subreddit, operation_id))
        conn.commit()
        return {"Status": "True"}
        conn.close()
    except sqlite3.IntegrityError as e:
        print(e)
        return {"Status": "Error Duplicate"}


def list_ops(path):
    """
    List Operations
    only requires a path to the database
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        ops = cur.execute("SELECT operation_id, operation_name, alert_level FROM operations")
        data = ops.fetchall()
        return data
        print(ops.fetchall())
        conn.close()
    except sqlite3.DataError as e:
        print(e)


def set_alert(path, operation_id, level):
    """
    Used to update an alert level to a new one
    Alerts are from 0-100
    if a alert is greater or eq to alert level
    an alert is sent

    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("UPDATE operations SET alert_level = ? WHERE operation_id = ? ", (level, operation_id))
        conn.commit()
    except sqlite3.DatabaseError as e:
        print(e)
def get_alert_level(path, operation_id):
    """
    used to get get alert level
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        level = cur.execute("SELECT alert_level FROM operations WHERE operation_id = ?", (operation_id,))
        return level.fetchone()
    except sqlite3.DatabaseError as e:
        print(e)

def get_op_id(path, name):
    """
    gets operation id from name
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        op_name = cur.execute("SELECT operation_id FROM operations WHERE operation_name = ?", (name,))
        return op_name.fetchone()
        conn.close()
    except sqlite3.DataError as e:
        print(e)

def list_subreddits(path):
    """
    list monitored subreddits
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT * FROM reddit")
        return data.fetchall()
        conn.close()
    except sqlite3.DataError as e:
        print(e)

def add_discord(path, server_id, operation_id):
    """
    We Add a discord Server to the monitor list
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO discord(server_id, operation_id) values(?,?);", (server_id, operation_id))
        conn.commit()
        conn.close()
    except sqlite3.IntegrityError as duplicate_record:
        print(e)

def list_servers(path):
    """
    Listing Servers.
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        servers =  cur.execute("SELECT * from discord;")
        return servers.fetchall()
    except sqlite3.DataError as e:
        print(e)

def get_op_name(path, id):
    """
    return operation name matching id
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        name = cur.execute("SELECT operation_name FROM operations WHERE operation_id = ?;", (id,))
        return name.fetchone()
    except sqlite3.DataError as e:
        print(e)

def add_watch_word(path, word, operation_id):
    """
    Function used to add a word to the watchlist
    inputs:
    word (string)
    operation_id (int)
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO watch_list(word, operation_id) VALUES(?,?)", (word, operation_id))
        conn.commit()
    except sqlite3.IntegrityError as e:
        print("word is already in database.")

def delete_operation(path, operation_id):
    """
    used to remove a operation from the database
    inputs:
    db path (string)
    operation_id (int)
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("DELETE FROM operations WHERE operation_id = ?", (operation_id,))
        conn.commit()
    except Exception as e:
        print(e)

def log_user(path, username, source, website, operation_id):
    """
    used to add a user to the loot db
    inputs:
    db path (string)
    operation_id (int)
    source (string)
    hash_id (string)
    """
    # hash id used for data integerty, not for security
    hash_id = hash_(username + source + website)
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO users(username, website, source, hash_id, operation_id) VALUES(?,?,?,?,?)", (username, website, source, hash_id, int(operation_id),))
        conn.commit()
    except sqlite3.IntegrityError as duplicate:
        pass

def update_target(path, username, target_number):
    """
    used to update a user to the target list
    inputs:
    db path (string)
    operation_id
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("UPDATE users SET is_target = ? WHERE username = ?;", (target_number, username))
        conn.commit()
    except sqlite3.DataError as e:
        print(e)


def add_telegram(path, chan_id, operation_id, name):
    """
    used to add a telegram chat/group
    inputs:
    database path (string)
    chan_id (int)
    operation_id (int)
    name (string)
    """

    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO telegram(chan_id, name, operation_id) VALUES(?,?,?)", (chan_id, name, operation_id))
        conn.commit()
    except sqlite3.IntegrityError as duplicate_chat:
        print(f"{chan_id} {name} Was already in db!")

def list_telegram(path):
    """
    used to list telgram chats
    inputs:
    database path (string)
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT chan_id, name, operation_id FROM telegram")
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def add_twitter(path, username, operation_id):
    """
    used to add a twitter account to the database
    inputs:
    database path (string)
    username (string)
    operation_id (int)
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO twitter(username, operation_id) VALUES(?,?)", (username, operation_id))
        conn.commit()
    except sqlite3.IntegrityError:
        print(f"{username} is already in db")

def list_twitter(path):
    """
    used to list monitored twitter accounts
    inputs:
    path (string)
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT username, operation_id FROM twitter")
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def move_twitter(path, username, operation_id):
    """
    used to move a twitter username to a differant operation
    inputs:
    path (string)
    username (string)
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("UPDATE twitter SET operation_id = ? WHERE username = ?", (operation_id, username))
        conn.commit()
    except sqlite3.IntegrityError:
        print(f"Error Moving {username} to operation: {operation_id}\nMost Likly that operation does not exist")


def list_targets(path):
    """
    used to list targets
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT username, source, operation_id FROM users WHERE is_target = 1;")
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)


def get_words(path):
    """
    used to list watch words
    """
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT word, operation_id FROM watch_list")
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def add_person(path, operation_id, fname=None, lname=None):
    """Adds a person to the ungi database"""
    if fname == None:
        fname = "John"
    elif lname == None:
        lname = "Doe"
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO people(operation_id, last_name, first_name) VALUES(?,?,?)", (operation_id, lname, fname))
        conn.commit()
        conn.close()
    except sqlite3.DataError as e:
        print(e)

def list_people(path, operation_id=None, fname=None, lname=None):
    """List targeted people"""
    use_op = False
    use_lname = False
    use_fname = False
    use_full = False
    if operation_id is not None:
        use_op = True
    else:
        if fname == None:
            use_lname = True
        if lname == None:
            use_fname = True
        if fname and lname is not None:
            use_full = true
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        if use_op:
            data = cur.execute("SELECT * FROM people WHERE operation_id = ?", (operation_id))
            return data.fetchall()
        if use_fname:
            data = cur.execute("SELECT * FROM people WHERE first_name = ?", (fname))
            return data.fetchall()
        if use_lname:
            data = cur.execute("SELECT * FROM people WHERE last_name = ?", (lname))
            return data.fetchall()
        if use_full:
            data = cur.execute("SELECT * FROM people WHERE first_name = ? AND last_name = ?", (fname, lname))
            return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def twitter_by_operation(path, operation_id):
    """Used to list twitter users by operation id"""
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT USERNAME, operation_id FROM twitter WHERE operation_id = ?", (operation_id,))
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def add_telegram_bot(path, api_hash, api_id, phone="0-0-0-0"):
    """Used to add a bot api info to the database so it can be distributed"""
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO telegram_bots(api_hash, api_id, phone) VALUES(?,?,?)", (api_hash, api_id, phone))
        conn.commit()
    except sqlite3.IntegrityError as e:
        print(e)

def list_telegram_bots(path):
    """Used to list api_hash and api_id from the database for distributed telegram bots"""
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT api_hash, api_id, phone FROM telegram_bots")
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def add_discord_bot(path, token):
    """Used to add a discord bot to database so it can be distributed"""
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        cur.execute("INSERT INTO discord_bots(token) VALUES(?)", (token,))
        conn.commit()
    except sqlite3.IntegrityError as e:
        print(e)

def list_discord_bots(path):
    """Used to list api_hash and api_id from the database for distributed telegram bots"""
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT token FROM discord_bots")
        return data.fetchall()
    except sqlite3.DataError as e:
        print(e)

def add_rss(path, operation_id, feed_url):
    """Add a feed to the ungi config db."""
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("INSERT INTO rss(operation_id, url) VALUES(?,?)", (operation_id, feed_url))
    except sqlite3.IntegrityError as e:
        print(e)
def list_rss(path):
 try:
     conn = sqlite.connect(path)
     cur = conn.cursor()
     data = cur.execute("SELECT operation_id, url FROM rss")
     return data.fetchall()
 except sqlite3.DataError as e:
  print(e)

def add_twitch_bot(path, oauth, client_id, nickname):
   try:
       conn = sqlite3.connect(path)
       cur = conn.cursor()
       data = cur.execute("INSERT INTO twitch_bots(oauth, client_id, nickname), VALUES(?,?,?)", (oauth, client_id, nickname))
       conn.commit()
   except sqlite3.IntegrityError as e:
       print(e)


def list_twitch_bots(path):
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT oauth, client_id, nickname FROM twitch_bots")
        return data.fetchall()
    except sqlite3.DatabaseError as e:
        print(e)


def add_twitch_channel(path, name, operation_id):
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("INSERT INTO twitch(name, operation_id) VALUES(?,?)", (name, operation_id))
        conn.commit()
    except sqlite3.IntegrityError as e:
        print(e)

def list_twitch(path):
    try:
        conn = sqlite3.connect(path)
        cur = conn.cursor()
        data = cur.execute("SELECT name, operation_id FROM twitch")
        return data.fetchall()
    except sqlite3.DatabaseError as e:
        print(e)



#!/usr/bin/env python3

import re
import requests
import bleach # no way in hell we trust element to not get pwned
import aiohttp, asyncio

def get_hashtags(input_string):
    """
    used to get #hastags from a inout string
    often you can find them in telegram chats
    """
    if len(input_string) > 0:
        hashtags = []
        r = re.compile("(#)+(\w{2,32})")
        for match in r.finditer(input_string):
            hashtags.append(match.group())
        return hashtags



def fix_up(str_in):
    """
    used to fix strings before being passed to the
    entity extractor
    """
    if str_in:
        no_ws = re.sub("\s+", " ", str_in)
        no_hashes = re.sub("(#)+(\w{2,32})", "", no_ws)
        no_hashes = re.sub('http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))', '', no_hashes, flags=re.MULTILINE)
        no_hashes = re.sub('[\S]+\.(net|com|org|info|edu|gov|uk|de|ca|jp|fr|au|us|ru|ch|it|nel|se|no|es|mil)[\S]*\s?','', no_hashes, flags=re.MULTILINE)
        clean = no_hashes.lower()

    return clean


def send_alert(message, username, source, event_type, endpoint, path=None):
    data = {}
    data["source"] = source
    data["message"] = message
    data["type"] = event_type
    data["username"] = username
    if path:
        data["path"] = path
    try:
        requests.post(endpoint, json=data)
    except requests.exceptions.RequestException as e:
        print(e)


def safe(str_in):
    """
    used to clean up textbefore being sent.
    that way so targets can not mass ping in the
    alert destinations
    """
    clean = str_in.replace("@", ".@")
    clean = bleach.clean(clean)
    return clean


class Imgbb():
    """Used to upload files to imgbb"""
    def __init__(self, key, session=None):
        self.key = key
        self.url = "https://api.imgbb.com/1/upload"
        if session is None:
            self.session = aiohttp.ClientSession()
            self.close = True
        else:
            self.session = session

    async def post(self, filename, name):
        """post by filename"""
        with open(filename, "rb") as image:
            data = {"key": self.key,
                    "image": image.read(),
                    "name": name}
            async with self.session.post(self.url, data=data) as response:
                resp = await response.json()
                return resp

            if self.close:
                self.session.close()
